@@ -23,6 +23,8 @@ from cognite.experimental.data_classes import (
     FunctionSchedulesList,
 )
 
+LIST_LIMIT_DEFAULT = 25
+LIST_LIMIT_CEILING = 10_000  # variable used to guarantee all items are returned when list(limit) is None, inf or -1.
 HANDLER_FILE_NAME = "handler.py"
 MAX_RETRIES = 5
 
@@ -162,9 +164,12 @@ class FunctionsAPI(APIClient):
         """
         self._delete_multiple(ids=id, external_ids=external_id, wrap_ids=True)
 
-    def list(self) -> FunctionList:
+    def list(self, limit: Optional[int] = LIST_LIMIT_DEFAULT) -> FunctionList:
         """`List all functions. <https://docs.cognite.com/api/playground/#operation/get-function>`_
 
+        Args:
+            limit (int, optional): Maximum number of functions to list. Pass in -1, float('inf') or None to list all functions.
+
         Returns:
             FunctionList: List of functions
 
@@ -177,11 +182,16 @@ class FunctionsAPI(APIClient):
                 >>> functions_list = c.functions.list()
         """
         url = "/functions"
-        res = self._get(url)
+
+        if limit in [float("inf"), -1, None]:
+            limit = LIST_LIMIT_CEILING
+
+        params = {"limit": limit}
+        res = self._get(url, params=params)
         return FunctionList._load(res.json()["items"], cognite_client=self._cognite_client)
 
     def retrieve(self, id: Optional[int] = None, external_id: Optional[str] = None) -> Optional[Function]:
-        """`Retrieve a single function by id. <https://docs.cognite.com/api/playground/#operation/get-api-playground-projects-project-functions-function_name>`_
+        """`Retrieve a single function by id. <https://docs.cognite.com/api/playground/#operation/post-api-playground-projects-project-context-functions-byids>`_
 
         Args:
             id (int, optional): ID
@@ -387,6 +397,8 @@ def _validate_function_handle(function_handle):
 
 
 class FunctionCallsAPI(APIClient):
+    _LIST_CLASS = FunctionCallList
+
     def list(
         self,
         function_id: Optional[int] = None,
@@ -395,10 +407,12 @@ class FunctionCallsAPI(APIClient):
         schedule_id: Optional[int] = None,
         start_time: Optional[Dict[str, int]] = None,
         end_time: Optional[Dict[str, int]] = None,
+        limit: Optional[int] = LIST_LIMIT_DEFAULT,
     ) -> FunctionCallList:
         """List all calls associated with a specific function id. Either function_id or function_external_id must be specified.
 
         Args:
+            limit (int, optional): Maximum number of function calls to list. Pass in -1, float('inf') or None to list all Function Calls.
             function_id (int, optional): ID of the function on which the calls were made.
             function_external_id (str, optional): External ID of the function on which the calls were made.
             status (str, optional): Status of the call. Possible values ["Running", "Failed", "Completed", "Timeout"].
@@ -428,16 +442,15 @@ class FunctionCallsAPI(APIClient):
         utils._auxiliary.assert_exactly_one_of_id_or_external_id(function_id, function_external_id)
         if function_external_id:
             function_id = self._cognite_client.functions.retrieve(external_id=function_external_id).id
-        url = f"/functions/{function_id}/calls/list"
         filter = {"status": status, "scheduleId": schedule_id, "startTime": start_time, "endTime": end_time}
-        post_body = {"filter": filter}
-        res = self._post(url, json=post_body)
-        return FunctionCallList._load(res.json()["items"], cognite_client=self._cognite_client)
+        resource_path = f"/functions/{function_id}/calls"
+
+        return self._list(method="POST", resource_path=resource_path, filter=filter, limit=limit)
 
     def retrieve(
         self, call_id: int, function_id: Optional[int] = None, function_external_id: Optional[str] = None
-    ) -> FunctionCall:
-        """`Retrieve call by id. <https://docs.cognite.com/api/playground/#operation/get-api-playground-projects-project-functions-function_name-calls-call_id>`_
+    ) -> Optional[FunctionCall]:
+        """`Retrieve a single function call by id. <https://docs.cognite.com/api/playground/#operation/byidsFunctionCalls>`_
 
         Args:
             call_id (int): ID of the call.
@@ -445,11 +458,11 @@ class FunctionCallsAPI(APIClient):
             function_external_id (str, optional): External ID of the function on which the call was made.
 
         Returns:
-            FunctionCall: Function call.
+            Optional[FunctionCall]: Requested function call.
 
         Examples:
 
-            Retrieve function call by id::
+            Retrieve single function call by id::
 
                 >>> from cognite.experimental import CogniteClient
                 >>> c = CogniteClient()
@@ -466,9 +479,8 @@ class FunctionCallsAPI(APIClient):
         utils._auxiliary.assert_exactly_one_of_id_or_external_id(function_id, function_external_id)
         if function_external_id:
             function_id = self._cognite_client.functions.retrieve(external_id=function_external_id).id
-        url = f"/functions/{function_id}/calls/{call_id}"
-        res = self._get(url)
-        return FunctionCall._load(res.json(), cognite_client=self._cognite_client)
+        resource_path = f"/functions/{function_id}/calls"
+        return self._retrieve_multiple(wrap_ids=True, resource_path=resource_path, ids=call_id)
 
     def get_response(self, call_id: int, function_id: Optional[int] = None, function_external_id: Optional[str] = None):
         """Retrieve the response from a function call.
@@ -542,9 +554,37 @@ class FunctionCallsAPI(APIClient):
 
 
 class FunctionSchedulesAPI(APIClient):
-    def list(self) -> FunctionSchedulesList:
+    _RESOURCE_PATH = "/functions/schedules"
+    _LIST_CLASS = FunctionSchedulesList
+
+    def retrieve(self, id: int) -> Optional[FunctionSchedule]:
+        """`Retrieve a single function schedule by id. <https://docs.cognite.com/api/playground/#operation/byidsFunctionSchedules>`_
+
+        Args:
+            id (int): ID
+
+        Returns:
+            Optional[FunctionSchedule]: Requested function schedule.
+
+
+        Examples:
+
+            Get function schedule by id::
+
+                >>> from cognite.experimental import CogniteClient
+                >>> c = CogniteClient()
+                >>> res = c.functions.schedules.retrieve(id=1)
+
+        """
+        utils._auxiliary.assert_exactly_one_of_id_or_external_id(id=id, external_id=None)
+        return self._retrieve_multiple(ids=id, wrap_ids=True)
+
+    def list(self, limit: Optional[int] = LIST_LIMIT_DEFAULT) -> FunctionSchedulesList:
         """`List all schedules associated with a specific project. <https://docs.cognite.com/api/playground/#operation/get-api-playground-projects-project-functions-schedules>`_
 
+        Args:
+            limit (int, optional): Maximum number of schedules to list. Pass in -1, float('inf') or None to list all schedules.
+
         Returns:
             FunctionSchedulesList: List of function schedules
 
@@ -565,7 +605,12 @@ class FunctionSchedulesAPI(APIClient):
 
         """
         url = f"/functions/schedules"
-        res = self._get(url)
+
+        if limit in [float("inf"), -1, None]:
+            limit = LIST_LIMIT_CEILING
+
+        params = {"limit": limit}
+        res = self._get(url, params=params)
         return FunctionSchedulesList._load(res.json()["items"])
 
     def create(
