@@ -3,6 +3,12 @@ from typing import Dict, List, Union
 from cognite.client.data_classes import ContextualizationJob
 
 from cognite.experimental._context_client import ContextAPI
+from cognite.experimental.data_classes import (
+    PNIDConvertResults,
+    PNIDDetectionList,
+    PNIDDetectionPageList,
+    PNIDDetectResults,
+)
 
 
 class PNIDParsingAPI(ContextAPI):
@@ -17,7 +23,7 @@ class PNIDParsingAPI(ContextAPI):
         min_tokens: int = 1,
         file_id: int = None,
         file_external_id: str = None,
-    ) -> ContextualizationJob:
+    ) -> PNIDDetectResults:
         """Detect entities in a PNID.
         Note: All users on this CDF subscription with assets read-all and files read-all capabilities in the project,
         are able to access the data sent to this endpoint.
@@ -31,7 +37,7 @@ class PNIDParsingAPI(ContextAPI):
             partial_match (bool): Allow for a partial match (e.g. missing prefix).
             min_tokens (int): Minimal number of tokens a match must be based on
         Returns:
-            ContextualizationJob: Resulting queued job. Note that .results property of this job will block waiting for results."""
+            PNIDDetectResults: Resulting queued job. Note that .results property of this job will block waiting for results."""
 
         if not (
             all([isinstance(entity, str) for entity in entities])
@@ -53,16 +59,16 @@ class PNIDParsingAPI(ContextAPI):
             partial_match=partial_match,
             name_mapping=name_mapping,
             min_tokens=min_tokens,
+            job_cls=PNIDDetectResults,
         )
-        job.wait_for_completion()
+        job.wait_for_completion()  # TODO: _detect_after_hook should be handled by PNIDDetectResults
         if job.status == "Completed":
             job = self._detect_after_hook(job, entities_return, search_field)
         return job
 
     @staticmethod
     def _detect_before_hook(entities, search_field):
-        """To decide whether to use search_field or not and make sure the entities are of type List[str]
-        """
+        """To decide whether to use search_field or not and make sure the entities are of type List[str]"""
         entities_return = None
         if entities and isinstance(entities[0], dict):
             entities_return = entities.copy()
@@ -71,8 +77,7 @@ class PNIDParsingAPI(ContextAPI):
 
     @staticmethod
     def _detect_after_hook(job, entities_return, search_field):
-        """Insert the entities into the result if search_field is used
-        """
+        """Insert the entities into the result if search_field is used"""
         if entities_return:
             texts = {item.get("text") for item in job.result["items"]}
             entities_return = [entity for entity in entities_return if entity.get(search_field) in texts]
@@ -126,4 +131,20 @@ class PNIDParsingAPI(ContextAPI):
             file_external_id=file_external_id,
             items=items,
             grayscale=grayscale,
+            job_cls=PNIDConvertResults,
         )
+
+    def ocr(self, file_id: int,) -> PNIDDetectionPageList:
+        """Retrieve the cached raw OCR result. Only works when detect (or the vision ocr service) has already been used on the file.
+
+        Args:
+            file_id (int): ID of the file.
+
+        Returns:
+            PNIDDetectionPageList  (effectively List[PNIDDetectionList]): Cached OCR results, one list per page."""
+        res = self._post(f"{self._RESOURCE_PATH}/ocr", json={"fileId": file_id})
+        items = [
+            PNIDDetectionList._load(item["annotations"], cognite_client=self._cognite_client)
+            for item in res.json()["items"]
+        ]
+        return PNIDDetectionPageList(items, file_id=file_id)
